@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* GIO - GLib Input, Output and Streaming Library
  * 
  * Copyright (C) 2006-2007 Red Hat, Inc.
@@ -33,11 +32,11 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include <glib.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gio/gunixmounts.h>
-#include <glib/gurifuncs.h>
 
 #include "gvfsbackendburn.h"
 #include "gvfsmonitor.h"
@@ -345,7 +344,7 @@ g_vfs_backend_burn_init (GVfsBackendBurn *burn_backend)
   
   /* Translators: This is the name of the backend */
   g_vfs_backend_set_display_name (backend, _("Burn"));
-  g_vfs_backend_set_icon_name (backend, "gnome-fs-client");
+  g_vfs_backend_set_icon_name (backend, "computer");
   g_vfs_backend_set_user_visible (backend, FALSE);
 
   mount_spec = g_mount_spec_new ("burn");
@@ -810,18 +809,27 @@ try_set_display_name (GVfsBackend *backend,
 }
 
 static gboolean
-try_upload (GVfsBackend *backend,
-            GVfsJobUpload *job,
-            const char *destination,
-            const char *local_path,
-            GFileCopyFlags flags,
-            GFileProgressCallback progress_callback,
-            gpointer progress_callback_data)
+try_push (GVfsBackend *backend,
+          GVfsJobPush *job,
+          const char *destination,
+          const char *local_path,
+          GFileCopyFlags flags,
+          gboolean remove_source,
+          GFileProgressCallback progress_callback,
+          gpointer progress_callback_data)
 {
   VirtualNode *file, *dir;
   struct stat stat_buf;
   char *dirname, *basename;
-  
+
+  if (remove_source)
+    {
+      /* Fallback to copy & delete for now, fix that up later */
+      g_vfs_job_failed_literal (job, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                                _("Operation not supported by backend"));
+      return TRUE;
+    }
+
   if (g_stat (local_path, &stat_buf) == -1)
     {
       int errsv = errno;
@@ -960,7 +968,7 @@ g_vfs_backend_burn_class_init (GVfsBackendBurnClass *klass)
   backend_class->try_create_dir_monitor = try_create_dir_monitor;
   backend_class->try_make_directory = try_make_directory;
   backend_class->try_set_display_name = try_set_display_name;
-  backend_class->try_upload = try_upload;
+  backend_class->try_push = try_push;
   backend_class->try_delete = try_delete;
   backend_class->read = do_read;
   backend_class->seek_on_read = do_seek_on_read;
