@@ -381,8 +381,8 @@ set_error_if_http_failed (SoupMessage *msg, GError **error)
 {
   if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
     {
-      g_set_error (error, SOUP_HTTP_ERROR,
-		   msg->status_code, "%s", msg->reason_phrase);
+      g_set_error_literal (error, SOUP_HTTP_ERROR,
+			   msg->status_code, msg->reason_phrase);
       return TRUE;
     }
   return FALSE;
@@ -714,6 +714,7 @@ read_async_done (GInputStream *stream)
   soup_input_stream_done_io (stream);
 
   g_simple_async_result_complete (result);
+  g_object_unref (result);
 }
 
 static void
@@ -748,6 +749,7 @@ soup_input_stream_read_async (GInputStream        *stream,
     {
       g_simple_async_result_set_op_res_gssize (result, 0);
       g_simple_async_result_complete_in_idle (result);
+      g_object_unref (result);
       return;
     }
 
@@ -756,6 +758,7 @@ soup_input_stream_read_async (GInputStream        *stream,
       gsize nread = read_from_leftover (priv, buffer, count);
       g_simple_async_result_set_op_res_gssize (result, nread);
       g_simple_async_result_complete_in_idle (result);
+      g_object_unref (result);
       return;
     }
 
@@ -804,6 +807,7 @@ soup_input_stream_close_async (GInputStream       *stream,
     }
 
   g_simple_async_result_complete_in_idle (result);
+  g_object_unref (result);
 }
 
 static gboolean
@@ -849,8 +853,8 @@ soup_input_stream_seek (GSeekable     *seekable,
        * We could find the Content-Length by doing a HEAD...
        */
 
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-                   "G_SEEK_END not currently supported");
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+	                   "G_SEEK_END not currently supported");
       return FALSE;
     }
 
@@ -902,8 +906,8 @@ soup_input_stream_truncate (GSeekable     *seekable,
 			    GCancellable  *cancellable,
 			    GError       **error)
 {
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-	       "Truncate not allowed on input stream");
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+		       "Truncate not allowed on input stream");
   return FALSE;
 }
 
