@@ -127,7 +127,7 @@ trash_item_escape_name (GFile    *file,
         }
 
       g_free (uri);
-      *src = '\0';
+      *dest = '\0';
 
       return escaped;
     }
@@ -492,8 +492,8 @@ trash_item_delete (TrashItem  *item,
   g_object_unref (expunged);
 
   if (!success)
-    g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                 "Failed to delete the item from the trash");
+    g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                         "Failed to delete the item from the trash");
 
   return success;
 }
